@@ -50,14 +50,12 @@ package Astro::Coord::ECI::Star;
 use strict;
 use warnings;
 
-our $VERSION = '0.130_01';
+our $VERSION = '0.130_02';
 
 use base qw{Astro::Coord::ECI};
 
 use Astro::Coord::ECI::Utils qw{ @CARP_NOT :mainstream };
 use Carp;
-use Data::Dumper;
-use POSIX qw{floor strftime};
 
 =item $star = Astro::Coord::ECI::Star->new();
 
